v1.2.0
=======
- bugfix in editors & readers attributes for the ResearchObject. Previously if string provided instead of list a list would be enforced in the way that was not desired
- fork/snapshot/archive now displaying additonal warnings to the user if the execution of the job was associated with any warnings
- additional parameter that enables filtering out inactive licenses added to :func:`rohub.list_custom_licenses`
- :func:`ResarchObject.show_full_metadata` is now displaying results as Pandas DataFrame
- :func:`rohub.ros_completeness` renamed to :func:`rohub.ros_assess_completeness` and :func:`ResarchObject.completeness` renamed to :func:`ResarchObject.assess_completeness`
- :func:`rohub.ros_assess_completeness` & :func:`ResarchObject.assess_completeness` both extended with additional parameters - checklist and target
- :func:`rohub.ros_content` is now using content/full endpoint as the previous one was not working any longer
- :func:`rohub.resource_find` is now using Elastic endpoint to perform search in more time efficient way
- :func:`rohub.external_user_delete` was removed and it is now only a part of an admin module due to the privilgies required to perform this action
- :func:`rohub.zenodo_list_funders` was fixed due to the changes in the JSON specification on Zenodo end
- :func:`rohub.zenodo_list_grants` was fixed due to the changes in the JSON specification on Zenodo end
- bugfix in :func:`ResarchObject.update` related to the creation mode being validated before making PUT request which causes unnecessary errors
- Introduction of a Folder object that is now being created in the library as an output of the following function: :func:`rohub.ros_add_folders`
- change in :func:`Resource.delete`; the function is not suppose to return anything. The prompt if deleting operation was successfull will be displayed to the user
- fixing redirect flag in :func:`rohub.resource_download`. It now uses dedicated endpoint to generate redirected links if one was requested using redirect flag


- added functions: 
    * :func:`rohub.delete_editors`
    * :func:`rohub.delete_readers`
    * :func:`ResarchObject.delete_editors`
    * :func:`ResarchObject.delete_readers`
    * :func:`rohub.adam_platform_metadata_find`
    * :func:`rohub.ros_assess_fairness`
    * :func:`rohub.ros_read_fairness`
    * :func:`ResarchObject.assess_fairness`
    * :func:`ResarchObject.read_fairness`
    * :func:`rohub.list_accepted_dmp_templates`
    * :func:`rohub.process_dmp_template`
    * :func:`rohub.show_dmp_mapping`
    * :func:`rohub.import_dmp`
    * :func:`rohub.ros_read_completeness`
    * :func:`ResarchObject.read_completeness`
    * :func:`rohub.ros_read_enrichment`
    * :func:`ResarchObject.read_enrichment`
    * :func:`rohub.ros_read_stability`
    * :func:`ResarchObject.read_stability`
    * :func:`rohub.ros_assess_stability`
    * :func:`ResarchObject.assess_stability`
    * :func:`rohub.ros_read_extended_analytics`
    * :func:`ResarchObject.read_extended_analytics`
    * :func:`rohub.ros_assess_extended_analytics`
    * :func:`ResarchObject.assess_extended_analytics`
    * :func:`rohub.ros_show_activities`
    * :func:`ResarchObject.show_activities`
    * :func:`rohub.show_relations`
    * :func:`rohub.ros_find_using_geoshape`
    * :func:`rohub.ros_recommend`
    * :func:`rohub.ros_recommend`
    * :func:`ResarchObject.recommend`
    * :func:`rohub.ontologies_find`
    * :func:`rohub.comments_find`
    * :func:`rohub.comments_create`
    * :func:`rohub.ros_show_rating`
    * :func:`ResarchObject.show_rating`
    * :func:`rohub.metadata_flatten`
    * :func:`ResarchObject.metadata_flatten`
    * :func:`Resource.metadata_flatten`
    * :func:`rohub.folder_search_using_id`
    * :func:`rohub.folder_load`
    * :func:`rohub.folder_update`
    * :func:`Folder.show_metadata`
    * :func:`Folder.show_full_metadata`
    * :func:`Folder.update`
    * :func:`Folder.delete`
    * :func:`rohub.ros_create_permission_link`
    * :func:`rohub.ros_show_details_using_permission_id`
